@@ -496,9 +496,6 @@ void Content::addContent(Content *c, bool prepend)
             }
         }
 
-        // Adjust the Content-Type of the newly created sub-Content.
-        main->contentType()->setCategory(Headers::CCmixedPart);
-
         // Move the body to the new subcontent.
         main->setBody(d->body);
         d->body.clear();
@@ -510,7 +507,6 @@ void Content::addContent(Content *c, bool prepend)
         Headers::ContentType *ct = contentType();
         ct->setMimeType("multipart/mixed");
         ct->setBoundary(multiPartBoundary());
-        ct->setCategory(Headers::CCcontainer);
         auto cte = contentTransferEncoding();
         cte->setEncoding(Headers::CE7Bit);
         cte->setDecoded(true);
@@ -931,7 +927,6 @@ bool ContentPrivate::parseUuencoded(Content *q)
         body.clear();
         ct->setMimeType("multipart/mixed");
         ct->setBoundary(multiPartBoundary());
-        ct->setCategory(Headers::CCcontainer);
         auto cte = q->contentTransferEncoding();
         cte->setEncoding(Headers::CE7Bit);
         cte->setDecoded(true);
@@ -950,11 +945,13 @@ bool ContentPrivate::parseUuencoded(Content *q)
         for (int i = 0; i < uup.binaryParts().count(); ++i) {
             auto c = new Content(q);
             c->contentType()->setMimeType(uup.mimeTypes().at(i));
-            c->contentType()->setName(QLatin1String(uup.filenames().at(i)), QByteArray(/*charset*/));
+            c->contentType()->setName(QLatin1StringView(uup.filenames().at(i)),
+                                      QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEuuenc);
             c->contentTransferEncoding()->setDecoded(false);
             c->contentDisposition()->setDisposition(Headers::CDattachment);
-            c->contentDisposition()->setFilename(QLatin1String(uup.filenames().at(i)));
+            c->contentDisposition()->setFilename(
+                QLatin1StringView(uup.filenames().at(i)));
             // uup.binaryParts().at(i) does no longer have the uuencode header, which makes KCodecs fail since 5c66308c4786ef7fbf77b0e306e73f7d4ac3431b
             c->setBody(prevBody);
             c->changeEncoding(Headers::CEbase64);   // Convert to base64.
@@ -987,7 +984,6 @@ bool ContentPrivate::parseYenc(Content *q)
         body.clear();
         ct->setMimeType("multipart/mixed");
         ct->setBoundary(multiPartBoundary());
-        ct->setCategory(Headers::CCcontainer);
         auto cte = q->contentTransferEncoding();
         cte->setEncoding(Headers::CE7Bit);
         cte->setDecoded(true);
@@ -1006,10 +1002,12 @@ bool ContentPrivate::parseYenc(Content *q)
         for (int i = 0; i < yenc.binaryParts().count(); i++) {
             auto c = new Content(q);
             c->contentType()->setMimeType(yenc.mimeTypes().at(i));
-            c->contentType()->setName(QLatin1String(yenc.filenames().at(i)), QByteArray(/*charset*/));
+            c->contentType()->setName(QLatin1StringView(yenc.filenames().at(i)),
+                                      QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEbinary);
             c->contentDisposition()->setDisposition(Headers::CDattachment);
-            c->contentDisposition()->setFilename(QLatin1String(yenc.filenames().at(i)));
+            c->contentDisposition()->setFilename(
+                QLatin1StringView(yenc.filenames().at(i)));
             c->setBody(yenc.binaryParts().at(i));     // Yenc bodies are binary.
             c->changeEncoding(Headers::CEbase64);   // Convert to base64.
             multipartContents.append(c);
@@ -1034,14 +1032,6 @@ bool ContentPrivate::parseMultipart(Content *q)
     preamble = mpp.preamble();
     epilogue = mpp.epilouge();
 
-    // Determine the category of the subparts (used in attachments()).
-    Headers::contentCategory cat;
-    if (ct->isSubtype("alternative")) {
-        cat = Headers::CCalternativePart;
-    } else {
-        cat = Headers::CCmixedPart; // Default to "mixed".
-    }
-
     // Create a sub-Content for every part.
     Q_ASSERT(multipartContents.isEmpty());
     body.clear();
@@ -1051,7 +1041,6 @@ bool ContentPrivate::parseMultipart(Content *q)
         c->setContent(part);
         c->setFrozen(frozen);
         c->parse();
-        c->contentType()->setCategory(cat);
         multipartContents.append(c);
     }
 
