@@ -391,7 +391,7 @@ QString MailboxList::displayString() const
             return QString::fromLatin1(mbox.address());
         }
     }
-    return displayNames().join(QLatin1String(", "));
+    return displayNames().join(QLatin1StringView(", "));
 }
 
 Types::Mailbox::List MailboxList::mailboxes() const
@@ -501,7 +501,7 @@ QString AddressList::asUnicodeString() const
             rv.append(mbox.prettyAddress());
         }
     }
-    return rv.join(QLatin1String(", "));
+    return rv.join(QLatin1StringView(", "));
 }
 
 void AddressList::clear()
@@ -567,7 +567,7 @@ QStringList AddressList::displayNames() const
 QString AddressList::displayString() const
 {
     // optimize for single entry and avoid creation of the QStringList in that case?
-    return displayNames().join(QLatin1String(", "));
+    return displayNames().join(QLatin1StringView(", "));
 }
 
 Types::Mailbox::List AddressList::mailboxes() const
@@ -697,7 +697,7 @@ QByteArray PhraseList::as7BitString(bool withHeaderType) const
 
 QString PhraseList::asUnicodeString() const
 {
-    return d_func()->phraseList.join(QLatin1String(", "));
+  return d_func()->phraseList.join(QLatin1StringView(", "));
 }
 
 void PhraseList::clear()
@@ -1626,7 +1626,6 @@ bool ContentType::isEmpty() const {
 
 void ContentType::clear() {
     Q_D(ContentType);
-    d->category = CCsingle;
     d->mimeType.clear();
     Parametrized::clear();
 }
@@ -1677,12 +1676,6 @@ QByteArray ContentType::subType() const {
 void ContentType::setMimeType(const QByteArray & mimeType) {
     Q_D(ContentType);
     d->mimeType = mimeType;
-
-    if (isMultipart()) {
-        d->category = CCcontainer;
-    } else {
-        d->category = CCsingle;
-    }
 }
 
 bool ContentType::isMediatype(const char *mediatype) const {
@@ -1790,15 +1783,6 @@ int ContentType::partialCount() const {
     }
 }
 
-contentCategory ContentType::category() const {
-    return d_func()->category;
-}
-
-void ContentType::setCategory(contentCategory c) {
-    Q_D(ContentType);
-    d->category = c;
-}
-
 void ContentType::setPartialParams(int total, int number) {
     setParameter(QStringLiteral("number"), QString::number(number));
     setParameter(QStringLiteral("total"), QString::number(total));
@@ -1841,7 +1825,7 @@ bool ContentType::parse(const char *&scursor, const char *const send,
     // parameter list
     eatCFWS(scursor, send, isCRLF);
     if (scursor == send) {
-        goto success; // no parameters
+        return true; // no parameters
     }
     if (*scursor != ';') {
         return false;
@@ -1852,13 +1836,6 @@ bool ContentType::parse(const char *&scursor, const char *const send,
         return false;
     }
 
-    // adjust category
-success:
-    if (isMultipart()) {
-        d->category = CCcontainer;
-    } else {
-        d->category = CCsingle;
-    }
     return true;
 }
 
